"""Base rope package

This package contains rope core modules that are used by other modules
and packages.

"""

__all__ = ["project", "libutils", "exceptions"]
